@@ -369,7 +369,7 @@ gconf_server_load_sources(void)
           error = NULL;
         }
       
-      g_slist_free(addresses);
+      gconf_address_list_free(addresses);
 
       g_assert(sources != NULL);
 
@@ -708,6 +708,9 @@ main(int argc, char** argv)
       daemon_lock = gconf_get_lock (lock_dir, &err);
     }
 
+  g_free (gconfd_dir);
+  g_free (lock_dir);
+
   if (daemon_lock != NULL)
     {
       /* This loads backends and so on. It needs to be done before
@@ -1091,8 +1094,15 @@ no_databases_in_use (void)
   /* Only the default database still open, and
    * it has no listeners
    */
-  return db_list == NULL &&
-    gconf_listeners_count (default_db->listeners) == 0;
+
+  if (db_list == NULL)
+    return TRUE;
+
+  if (db_list->next == NULL &&
+      db_list->data == default_db)
+    return gconf_listeners_count (default_db->listeners) == 0;
+
+  return FALSE;
 }
 
 void
@@ -1145,7 +1155,16 @@ gconfd_notify_other_listeners (GConfDatabase *modified_db,
 		      return;
 		    }
 
-		  cvalue = gconf_corba_value_from_gconf_value (value);
+		  if (value != NULL)
+		    {
+		      cvalue = gconf_corba_value_from_gconf_value (value);
+		      gconf_value_free (value);
+		    }
+		  else
+		    {
+		      cvalue = gconf_invalid_corba_value ();
+		    }
+
 		  gconf_database_notify_listeners (db,
 						   NULL,
 						   key,
@@ -1154,7 +1173,6 @@ gconfd_notify_other_listeners (GConfDatabase *modified_db,
 						   is_writable,
 						   FALSE);
 		  CORBA_free (cvalue);
-		  gconf_value_free (value);
 		}
 
 	      tmp2 = tmp2->next;
